==> vue-sb-components-2.4.1.tgz: package/components/form-autocomplete/form-autocomplete.js <==
import "./form-autocomplete.css";
import { defineComponent as $, openBlock as n, createElementBlock as l, Fragment as m, renderList as L, normalizeClass as v, withModifiers as S, createElementVNode as k, createCommentVNode as d, toDisplayString as w, resolveComponent as c, mergeProps as u, createVNode as g, withCtx as C, createBlock as y, Teleport as q, normalizeStyle as B } from "vue";
import T from "../progress-circular/progress-circular.js";
import P from "../form-input/form-input.js";
import { _ as b } from "../../_plugin-vue_export-helper-dad06003.js";
import { r as O } from "../../helper-4d4ed314.js";
const F = $({
  emits: {
    select: (e) => !0
  },
  props: {
    activeOption: {
      required: !0,
      type: Number
    },
    isLoading: {
      required: !1,
      type: Boolean
    },
    list: {
      required: !0,
      type: Object
    },
    loadingText: {
      default: "Loading...",
      type: String
    },
    term: {
      required: !0,
      type: String
    }
  },
  name: "sb-form-autocomplete-option",
  methods: {
    doSelect(e) {
      this.isLoading || this.$emit("select", e.value);
    },
    renderOpt({ label: e }) {
      const t = e.toLowerCase(), i = this.term.toLowerCase(), s = t.indexOf(i), o = e.substring(
        s,
        s + i.length
      );
      return e.substring(0, s) + `<b>${o}</b>` + e.substring(s + i.length);
    }
  }
}), E = ["onClick"], W = ["innerHTML"], A = {
  key: 1,
  class: "loading-text"
};
function I(e, t, i, s, o, a) {
  return n(), l(m, null, [
    e.isLoading ? d("", !0) : (n(!0), l(m, { key: 0 }, L(e.list, (p, h) => (n(), l("div", {
      class: v(["option", { focus: e.activeOption === h }]),
      key: `opt-${h}-${p.value}`,
      onClick: S((f) => e.doSelect(p), ["stop"])
    }, [
      k("span", {
        innerHTML: e.renderOpt(p)
      }, null, 8, W)
    ], 10, E))), 128)),
    e.isLoading ? (n(), l("div", A, w(e.loadingText), 1)) : d("", !0)
  ], 64);
}
const R = /* @__PURE__ */ b(F, [["render", I]]), M = $({
  emits: {
    "update:modelValue": (e) => !0,
    change: (e) => !0,
    input: (e) => !0
  },
  props: {
    disabled: {
      required: !1,
      type: Boolean
    },
    errorMessage: {
      required: !1,
      type: [String, Function]
    },
    flat: {
      required: !1,
      type: Boolean
    },
    isError: {
      required: !1,
      type: Boolean
    },
    isLoading: {
      required: !1,
      type: Boolean
    },
    label: {
      required: !1,
      type: String
    },
    list: {
      required: !1,
      type: Object
    },
    loadingText: {
      default: "Loading...",
      type: String
    },
    modelValue: {
      required: !1,
      type: String
    },
    placeholder: {
      required: !1,
      type: String
    },
    readOnly: {
      required: !1,
      type: Boolean
    },
    required: {
      required: !1,
      type: Boolean
    },
    value: {
      required: !1,
      type: String
    }
  },
  name: "sb-form-autocomplete",
  components: {
    OptionComponent: R,
    "sb-circular": T,
    "sb-input": P
  },
  data() {
    return {
      activeOption: -1,
      elem: null,
      icon: {
        onClick: null,
        placement: "append"
      },
      isFocus: !1,
      isOpen: !1,
      localList: [],
      localTerm: "",
      optWrapperStyles: {
        left: "0",
        top: "0",
        width: "0"
      },
      parentWithScroll: null
    };
  },
  methods: {
    doSelect(e) {
      this.isOpen = !1, this.handleRemoveFocus(), this.handleUpdateModel(e);
    },
    handleArrowEvent(e, t) {
      if (this.isOpen) {
        t.preventDefault();
        const i = document.querySelector(
          `[data-target="options-${this.$.uid}"]`
        );
        if (i) {
          const s = i.children;
          let o = this.activeOption + e;
          this.activeOption < 1 && o < 0 ? o = s.length - 1 : this.activeOption === s.length - 1 && o > s.length - 1 && (o = 0);
          const a = s.item(o);
          a == null || a.scrollIntoView(!1), this.activeOption = o;
        }
      }
    },
    handleBackdropClick() {
      this.handleRemoveFocus(), this.isOpen = !1;
    },
    handleFilterList(e) {
      this.localTerm = e, e = e.replace(/^\s?|\s?$/g, "").toLowerCase(), this.localList = [...this.list || []].filter(
        (t) => t.label.toLowerCase().includes(e)
      );
    },
    handleInput(e) {
      const t = e.target.value;
      this.handleFilterList(t), t != null && t.length ? (this.$emit("input", t), this.handleOpen()) : this.isOpen = !1;
    },
    handleKeyEvent(e) {
      if (e.key === "ArrowDown" || e.key === "ArrowUp") {
        const t = e.key === "ArrowDown" ? 1 : -1;
        this.isOpen || this.handleOpen(), this.$nextTick(() => this.handleArrowEvent(t, e));
      } else if (e.key === "Enter") {
        if (this.isOpen) {
          e.preventDefault(), e.stopPropagation();
          const t = document.querySelectorAll(
            `[data-target="options-${this.$.uid}"] .option`
          ), i = Array.from(
            t
          ).findIndex(
            (s) => s.classList.contains("focus") && !s.classList.contains("selected")
          );
          i > -1 && this.doSelect(this.localList[i]);
        }
      } else
        (e.key === "Escape" || e.key === "Tab") && (this.isOpen = !1, this.handleRemoveFocus());
    },
    handleOpen() {
      !this.readOnly && !this.disabled && !this.isOpen && (this.isOpen = !0, this.$nextTick(() => {
        this.setOptionsPosition();
      }));
    },
    handleParentBlur(e) {
      const t = e.target, i = e.relatedTarget;
      t.contains(i) || (this.isOpen = !1, this.handleRemoveFocus());
    },
    handleParentFocus() {
      const t = this.$el.getElementsByTagName("input");
      if ((t == null ? void 0 : t.length) > 0) {
        const i = t.item(0);
        i == null || i.focus();
      }
      this.isFocus = !0;
    },
    handleParentScroll(e) {
      const t = O(this.$el);
      this.parentWithScroll && this.parentWithScroll.removeEventListener("scroll", () => {
        this.setOptionsPosition();
      }), t && (e ? t.addEventListener("scroll", () => {
        this.setOptionsPosition();
      }) : t.removeEventListener("scroll", () => {
        this.setOptionsPosition();
      })), this.$nextTick(() => {
        this.parentWithScroll = t;
      });
    },
    handleRemoveFocus() {
      this.isFocus = !1;
      const e = this.$el;
      e.blur();
      const t = e.getElementsByTagName("input");
      if ((t == null ? void 0 : t.length) > 0) {
        const i = t.item(0);
        i == null || i.blur();
      }
    },
    handleUpdateModel(e) {
      this.$emit("update:modelValue", e), this.$emit("change", e);
    },
    setOptionsPosition() {
      var e;
      if (this.elem) {
        const t = this.elem.getBoundingClientRect(), i = (e = this.$refs["options-wrapper"]) == null ? void 0 : e.getBoundingClientRect();
        if (i)
          return document.body.getBoundingClientRect().height - (t.height + t.y) <= i.height ? this.optWrapperStyles = {
            left: `${t.x}px`,
            top: `${t.y - 6 - i.height}px`,
            width: `${t.width + 1}px`
          } : this.optWrapperStyles = {
            left: `${t.x}px`,
            top: `${t.y + t.height}px`,
            width: `${t.width + 1}px`
          };
      }
    }
  },
  watch: {
    isOpen(e) {
      this.handleParentScroll(e), e || (this.activeOption = -1, this.handleFilterList(""));
    },
    list: {
      deep: !0,
      handler(e) {
        e && (this.localList = [...e]);
      },
      immediate: !0
    },
    localList: {
      deep: !0,
      handler() {
        this.$nextTick(() => {
          this.setOptionsPosition();
        });
      }
    }
  },
  mounted() {
    const e = this.$refs["input-wrapper"].$el.children, t = Array.from(e).find(
      (i) => i.classList.contains("input-group")
    );
    t && (this.elem = t), this.elem && this.setOptionsPosition(), this.parentWithScroll = O(this.$el);
  },
  unmounted() {
    this.parentWithScroll && this.parentWithScroll.removeEventListener("scroll", () => {
      this.setOptionsPosition();
    });
  }
});
const V = ["data-target", "tabindex"], D = ["data-target"];
function N(e, t, i, s, o, a) {
  const p = c("sb-circular"), h = c("sb-input"), f = c("OptionComponent");
  return n(), l("div", u({
    class: ["autocomplete-wrapper", {
      expanded: e.isOpen,
      loading: e.isLoading
    }],
    "data-target": `autocomplete-${e.$.uid}`,
    tabindex: !e.disabled && !e.readOnly ? 0 : -1,
    ref: "autocomplete-wrapper"
  }, { ...e.$attrs }, {
    onBlur: t[1] || (t[1] = (...r) => e.handleParentBlur && e.handleParentBlur(...r)),
    onFocus: t[2] || (t[2] = (...r) => e.handleParentFocus && e.handleParentFocus(...r)),
    onKeydown: t[3] || (t[3] = (...r) => e.handleKeyEvent && e.handleKeyEvent(...r))
  }), [
    g(h, u({
      "error-message": e.errorMessage,
      icon: e.icon,
      "is-error": e.isError,
      "is-focus": e.isFocus,
      label: e.label,
      placeholder: e.placeholder,
      required: e.required,
      variant: e.flat ? "flat" : "default",
      ref: "input-wrapper"
    }, { disabled: e.disabled, modelValue: e.modelValue, readOnly: e.readOnly, value: e.value }, { onInput: e.handleInput }), {
      "icon-slot": C(() => [
        e.isLoading ? (n(), y(p, {
          key: 0,
          indeterminate: "",
          size: 20
        })) : d("", !0)
      ]),
      _: 1
    }, 16, ["error-message", "icon", "is-error", "is-focus", "label", "placeholder", "required", "variant", "onInput"]),
    (n(), y(q, { to: "body" }, [
      e.isOpen ? (n(), l("div", {
        key: 0,
        class: "sb-autocomplete-backdrop",
        onClick: t[0] || (t[0] = S((...r) => e.handleBackdropClick && e.handleBackdropClick(...r), ["stop"]))
      })) : d("", !0),
      e.isOpen ? (n(), l("div", {
        key: 1,
        class: v(["sb-autocomplete-result-wrapper", {
          expanded: e.isOpen
        }]),
        "data-target": `options-${e.$.uid}`,
        style: B(e.optWrapperStyles),
        ref: "options-wrapper"
      }, [
        g(f, u({
          "active-option": e.activeOption,
          "is-loading": e.isLoading,
          list: e.localList,
          term: e.localTerm
        }, {
          loadingText: e.loadingText
        }, { onSelect: e.doSelect }), null, 16, ["active-option", "is-loading", "list", "term", "onSelect"])
      ], 14, D)) : d("", !0)
    ]))
  ], 16, V);
}
const G = /* @__PURE__ */ b(M, [["render", N]]);
export {
  G as default
};

==> vue-sb-components-2.4.5.tgz: package/components/form-autocomplete/form-autocomplete.js <==
import "./form-autocomplete.css";
import { defineComponent as $, openBlock as n, createElementBlock as l, Fragment as f, renderList as L, normalizeClass as v, withModifiers as S, createElementVNode as k, createCommentVNode as d, toDisplayString as w, resolveComponent as u, mergeProps as c, createVNode as g, withCtx as B, createBlock as y, Teleport as C, normalizeStyle as q } from "vue";
import T from "../progress-circular/progress-circular.js";
import P from "../form-input/form-input.js";
import { _ as b } from "../../_plugin-vue_export-helper-dad06003.js";
import { r as O } from "../../helper-4d4ed314.js";
const F = $({
  emits: {
    select: (e) => !0
  },
  props: {
    activeOption: {
      required: !0,
      type: Number
    },
    isLoading: {
      required: !1,
      type: Boolean
    },
    list: {
      required: !0,
      type: Object
    },
    loadingText: {
      default: "Loading...",
      type: String
    },
    term: {
      required: !0,
      type: String
    }
  },
  name: "sb-form-autocomplete-option",
  methods: {
    doSelect(e) {
      this.isLoading || this.$emit("select", e.value);
    },
    renderOpt({ label: e }) {
      const t = e.toLowerCase(), i = this.term.toLowerCase(), o = t.indexOf(i), s = e.substring(
        o,
        o + i.length
      );
      return e.substring(0, o) + `<b>${s}</b>` + e.substring(o + i.length);
    }
  }
}), E = ["onClick"], W = ["innerHTML"], A = {
  key: 1,
  class: "loading-text"
};
function R(e, t, i, o, s, a) {
  return n(), l(f, null, [
    e.isLoading ? d("", !0) : (n(!0), l(f, { key: 0 }, L(e.list, (p, h) => (n(), l("div", {
      class: v(["option", { focus: e.activeOption === h }]),
      key: `opt-${h}-${p.value}`,
      onClick: S((m) => e.doSelect(p), ["stop"])
    }, [
      k("span", {
        innerHTML: e.renderOpt(p)
      }, null, 8, W)
    ], 10, E))), 128)),
    e.isLoading ? (n(), l("div", A, w(e.loadingText), 1)) : d("", !0)
  ], 64);
}
const I = /* @__PURE__ */ b(F, [["render", R]]), M = $({
  emits: {
    "update:modelValue": (e) => !0,
    change: (e) => !0,
    input: (e) => !0
  },
  props: {
    disabled: {
      required: !1,
      type: Boolean
    },
    errorMessage: {
      required: !1,
      type: [String, Function]
    },
    flat: {
      required: !1,
      type: Boolean
    },
    isError: {
      required: !1,
      type: Boolean
    },
    isLoading: {
      required: !1,
      type: Boolean
    },
    label: {
      required: !1,
      type: String
    },
    list: {
      required: !1,
      type: Object
    },
    loadingText: {
      default: "Loading...",
      type: String
    },
    modelValue: {
      required: !1,
      type: String
    },
    placeholder: {
      required: !1,
      type: String
    },
    readOnly: {
      required: !1,
      type: Boolean
    },
    required: {
      required: !1,
      type: Boolean
    },
    value: {
      required: !1,
      type: String
    }
  },
  name: "sb-form-autocomplete",
  components: {
    OptionComponent: I,
    "sb-circular": T,
    "sb-input": P
  },
  data() {
    return {
      activeOption: -1,
      elem: null,
      icon: {
        onClick: null,
        placement: "append"
      },
      isFocus: !1,
      isOpen: !1,
      localList: [],
      localTerm: "",
      optWrapperStyles: {
        left: "0",
        top: "0",
        width: "0"
      },
      parentWithScroll: null
    };
  },
  methods: {
    doSelect(e) {
      this.isOpen = !1, this.handleRemoveFocus(), this.handleUpdateModel(e);
    },
    handleArrowEvent(e, t) {
      if (this.isOpen) {
        t.preventDefault();
        const i = document.querySelector(
          `[data-target="options-${this.$.uid}"]`
        );
        if (i) {
          const o = i.children;
          let s = this.activeOption + e;
          this.activeOption < 1 && s < 0 ? s = o.length - 1 : this.activeOption === o.length - 1 && s > o.length - 1 && (s = 0);
          const a = o.item(s);
          a == null || a.scrollIntoView(!1), this.activeOption = s;
        }
      }
    },
    handleBackdropClick() {
      this.handleRemoveFocus(), this.isOpen = !1;
    },
    handleFilterList(e) {
      this.localTerm = e, e = e.replace(/^\s?|\s?$/g, "").toLowerCase(), this.localList = [...this.list || []].filter(
        (t) => t.label.toLowerCase().includes(e)
      );
    },
    handleInput(e) {
      const t = e.target.value;
      this.handleFilterList(t), this.handleUpdateModel(t), t != null && t.length ? (this.$emit("input", t), this.handleOpen()) : this.isOpen = !1;
    },
    handleKeyEvent(e) {
      if (e.key === "ArrowDown" || e.key === "ArrowUp") {
        const t = e.key === "ArrowDown" ? 1 : -1;
        this.isOpen || this.handleOpen(), this.$nextTick(() => this.handleArrowEvent(t, e));
      } else if (e.key === "Enter") {
        if (this.isOpen) {
          e.preventDefault(), e.stopPropagation();
          const t = document.querySelectorAll(
            `[data-target="options-${this.$.uid}"] .option`
          ), i = Array.from(
            t
          ).findIndex(
            (o) => o.classList.contains("focus") && !o.classList.contains("selected")
          );
          i > -1 && this.doSelect(this.localList[i]);
        }
      } else
        (e.key === "Escape" || e.key === "Tab") && (this.isOpen = !1, this.handleRemoveFocus());
    },
    handleOpen() {
      !this.readOnly && !this.disabled && !this.isOpen && (this.isOpen = !0, this.$nextTick(() => {
        this.setOptionsPosition();
      }));
    },
    handleParentBlur(e) {
      const t = e.target, i = e.relatedTarget;
      t.contains(i) || (this.isOpen = !1, this.handleRemoveFocus());
    },
    handleParentFocus() {
      const t = this.$el.getElementsByTagName("input");
      if ((t == null ? void 0 : t.length) > 0) {
        const i = t.item(0);
        i == null || i.focus();
      }
      this.isFocus = !0;
    },
    handleParentScroll(e) {
      const t = O(this.$el);
      this.parentWithScroll && this.parentWithScroll.removeEventListener("scroll", () => {
        this.setOptionsPosition();
      }), t && (e ? t.addEventListener("scroll", () => {
        this.setOptionsPosition();
      }) : t.removeEventListener("scroll", () => {
        this.setOptionsPosition();
      })), this.$nextTick(() => {
        this.parentWithScroll = t;
      });
    },
    handleRemoveFocus() {
      this.isFocus = !1;
      const e = this.$el;
      e.blur();
      const t = e.getElementsByTagName("input");
      if ((t == null ? void 0 : t.length) > 0) {
        const i = t.item(0);
        i == null || i.blur();
      }
    },
    handleUpdateModel(e) {
      this.$emit("update:modelValue", e), this.$emit("change", e);
    },
    setOptionsPosition() {
      var e;
      if (this.elem) {
        const t = this.elem.getBoundingClientRect(), i = (e = this.$refs["options-wrapper"]) == null ? void 0 : e.getBoundingClientRect();
        if (i)
          return document.body.getBoundingClientRect().height - (t.height + t.y) <= i.height ? this.optWrapperStyles = {
            left: `${t.x}px`,
            top: `${t.y - 6 - i.height}px`,
            width: `${t.width + 1}px`
          } : this.optWrapperStyles = {
            left: `${t.x}px`,
            top: `${t.y + t.height}px`,
            width: `${t.width + 1}px`
          };
      }
    }
  },
  watch: {
    isOpen(e) {
      this.handleParentScroll(e), e || (this.activeOption = -1, this.handleFilterList(""));
    },
    list: {
      deep: !0,
      handler(e) {
        e && (this.localList = [...e]);
      },
      immediate: !0
    },
    localList: {
      deep: !0,
      handler() {
        this.$nextTick(() => {
          this.setOptionsPosition();
        });
      }
    }
  },
  mounted() {
    const e = this.$refs["input-wrapper"].$el.children, t = Array.from(e).find(
      (i) => i.classList.contains("input-group")
    );
    t && (this.elem = t), this.elem && this.setOptionsPosition(), this.parentWithScroll = O(this.$el);
  },
  unmounted() {
    this.parentWithScroll && this.parentWithScroll.removeEventListener("scroll", () => {
      this.setOptionsPosition();
    });
  }
});
const V = ["data-target", "tabindex"], D = ["data-target"];
function N(e, t, i, o, s, a) {
  const p = u("sb-circular"), h = u("sb-input"), m = u("OptionComponent");
  return n(), l("div", c({
    class: ["autocomplete-wrapper", {
      expanded: e.isOpen,
      loading: e.isLoading
    }],
    "data-target": `autocomplete-${e.$.uid}`,
    tabindex: !e.disabled && !e.readOnly ? 0 : -1,
    ref: "autocomplete-wrapper"
  }, { ...e.$attrs }, {
    onBlur: t[1] || (t[1] = (...r) => e.handleParentBlur && e.handleParentBlur(...r)),
    onFocus: t[2] || (t[2] = (...r) => e.handleParentFocus && e.handleParentFocus(...r)),
    onKeydown: t[3] || (t[3] = (...r) => e.handleKeyEvent && e.handleKeyEvent(...r))
  }), [
    g(h, c({
      "error-message": e.errorMessage,
      icon: e.icon,
      "is-error": e.isError,
      "is-focus": e.isFocus,
      label: e.label,
      placeholder: e.placeholder,
      required: e.required,
      variant: e.flat ? "flat" : "default",
      ref: "input-wrapper"
    }, { disabled: e.disabled, modelValue: e.modelValue, readOnly: e.readOnly, value: e.value }, {
      onBlur: e.handleRemoveFocus,
      onInput: e.handleInput
    }), {
      "icon-slot": B(() => [
        e.isLoading ? (n(), y(p, {
          key: 0,
          indeterminate: "",
          size: 20
        })) : d("", !0)
      ]),
      _: 1
    }, 16, ["error-message", "icon", "is-error", "is-focus", "label", "placeholder", "required", "variant", "onBlur", "onInput"]),
    (n(), y(C, { to: "body" }, [
      e.isOpen ? (n(), l("div", {
        key: 0,
        class: "sb-autocomplete-backdrop",
        onClick: t[0] || (t[0] = S((...r) => e.handleBackdropClick && e.handleBackdropClick(...r), ["stop"]))
      })) : d("", !0),
      e.isOpen ? (n(), l("div", {
        key: 1,
        class: v(["sb-autocomplete-result-wrapper", {
          expanded: e.isOpen
        }]),
        "data-target": `options-${e.$.uid}`,
        style: q(e.optWrapperStyles),
        ref: "options-wrapper"
      }, [
        g(m, c({
          "active-option": e.activeOption,
          "is-loading": e.isLoading,
          list: e.localList,
          term: e.localTerm
        }, {
          loadingText: e.loadingText
        }, { onSelect: e.doSelect }), null, 16, ["active-option", "is-loading", "list", "term", "onSelect"])
      ], 14, D)) : d("", !0)
    ]))
  ], 16, V);
}
const G = /* @__PURE__ */ b(M, [["render", N]]);
export {
  G as default
};
